/* -*-c-*- ---------------- mixgtk_colorsel.h :
 * Functions to handle the color selection customization
 * ------------------------------------------------------------------
 *  Last change: Time-stamp: <2001-04-22 00:52:11 jao>
 * ------------------------------------------------------------------
 * Copyright (C) 2001 Free Software Foundation, Inc.
 *  
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *  
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *  
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *  
 */


#ifndef MIXGTK_COLORSEL_H
#define MIXGTK_COLORSEL_H

#include <gtk/gtk.h>

/* init */
extern void
mixgtk_colorsel_init (void);


#endif /* MIXGTK_COLORSEL_H */

